@@ -3,6 +3,7 @@
 
 from PyQt4.QtGui import *
 from PyQt4.QtCore import *
+from PyQt4.QtMaemo5 import *
 import math
 import station
 
@@ -130,6 +131,8 @@ class Fond(QGraphicsView):
 class Carte(QGraphicsScene):
     fond = QGraphicsRectItem ()
     fond.setBrush(QBrush(QColor(0,0,0,153)))
+    
+    blurred = False
 
     def doubleClick  ( self, p ):
         self.emit(SIGNAL("dblclicked(QPointF)"),p)
@@ -137,9 +140,11 @@ class Carte(QGraphicsScene):
     def blur(self):
         self.fond.setRect(self.sceneRect())
         self.addItem(self.fond)
+        blurred = True
 
     def unblur(self):
         self.removeItem(self.fond)
+        blurred = False
 
 
       
@@ -260,17 +265,19 @@ class PanAction(QLabel):
             self.toggle = False
             self.animX.start()
             self.setPixmap(QPixmap("/usr/share/icons/hicolor/48x48/hildon/statusarea_sharing_pending.png"))
+            
 
 #Boutton Du GPS
 
 class GpsButton(QLabel):   
     def __init__(self, parent=None):
         super(GpsButton, self).__init__(parent)
-        self.pixNo = QPixmap("/usr/share/icons/hicolor/48x48/hildon/location_applet_off.png")
+        self.pixNo = QPixmap("/usr/share/icons/hicolor/32x32/hildon/camera_gps_location.png")
         self.pixOn = QPixmap("/usr/share/icons/hicolor/48x48/hildon/location_applet_track_start.png")
         self.pixGood = QPixmap("/usr/share/icons/hicolor/48x48/hildon/location_applet_track_stop_ani.png")
         self.pixOff = QPixmap("/usr/share/icons/hicolor/48x48/hildon/sketch_circle.png")
         
+        self.setAlignment(Qt.AlignCenter)
         self.setPixmap (  self.pixNo)
         self.state = False
         
@@ -362,22 +369,95 @@ class Gps(QGraphicsEllipseItem):
         
         
 
-class diagAmbig(QWidget):   
-    def __init__(self, liste, parent=None):
+class diagSearch(QWidget):
+    def __init__(self, graph, parent=None):
         super(diagSearch, self).__init__(parent)
-        self.hide()
-        self.setGeometry(0,0,parent.width(),400)
-        self.Layout = QVBoxLayout(self)
+        self.fond = QGraphicsRectItem (parent.scene().sceneRect())
+        self.fond.setBrush(QBrush(QColor(0,0,0,153)))
         
-        self.Line = QListWidget(self)
+        self.hide()
+        self.setGeometry(50,50,parent.width()-100,65)
+        self.graph = graph
+        
+      
+        self.Line = QLineEdit(self)
+#        self.Line.setStyleSheet("""QLineEdit {
+#     border: 4px solid palette(highlight);
+#     border-right : none;
+#     border-radius: 32px;
+#     padding-left: 16px;
+#     padding-right : 80px;
+#     color: white;
+#     selection-background-color: white;
+#     selection-color: black;
+# }""")
+        self.Line.setGeometry(0,0,self.width()-32,64)
 
-        self.Line.setStyleSheet("border-left:8px solid white; color: white;")
-        self.Line.setGeometry(self.width()/2-150,40,300,48)
+        self.Search = QPushButton("Go",self)
+
+        self.Search.setStyleSheet("QPushButton {font: bold 32px;border:4px solid white;color:white;border-radius: 32px;background-color: black;} QPushButton:pressed {background-color: palette(highlight);color:palette(highlighted-text);border-color:palette(highlighted-text);}")
+        self.Search.setGeometry(self.width()-64,0,64,64)
+        
+        self.List = QListWidget(self)
+#        self.List.setStyleSheet("QListView:item{border:2px solid white;border-top:0px ;color: white;}QListView:item:selected{border:4px solid white; color: black;background : white;}")
+        self.List.itemDoubleClicked.connect(self.selec)
+        self.List.setGeometry(32,64,0,0)
+        self.List.setWordWrap ( True )
+
+        self.Line.setFocus ( Qt.MouseFocusReason)
+        self.Line.returnPressed.connect(self.cherche)
+        self.Search.clicked.connect(self.cherche)
+        QObject.connect(self.parent(), SIGNAL("pressed()"), self.close)
+        
+    def cherche(self):
+        result = []
+        self.List.clear()
+        for element in self.graph:
+            if str(self.Line.text().toLower()) in element.lower():
+                result += [element]
+        if result == []:
+            QMaemo5InformationBox.information( self, 'La recherche n\'a donn\xe9 aucun r\xe9sultat.' )
+        elif len(element) == 1 or str(self.Line.text()) in result:
+            self.emit(SIGNAL("selected(QString)"),self.Line.text())
+            self.List.clear()
+            self.List.hide()
+            self.close()
+        else:
+            for stop in result:
+                self.List.addItem(stop)
+            self.resize(self.width(),min(self.height()+74*len(result),self.parent().height()-100))
+            self.List.resize(self.width()-64,min(74*len(result),self.height()-64))
+            self.List.show()
+        
+    def selec(self,it):
+        self.emit(SIGNAL("selected(QString)"),it.text())
+        self.List.clear()
+        self.List.hide()
+        self.close()
+        
+    def rotate(self):
+        self.resize(self.parent().width()-100,min(64+74*self.List.count(),self.parent().height()-100))
+        self.Line.resize(self.width(),64)
+        self.Search.setGeometry(self.width()-64,0,64,64)
+        self.List.resize(self.width()-64, min(74*self.List.count(),self.height()-64))
+
+    def showEvent(self,event):
+        self.parent().scene().addItem(self.fond)
+        QWidget.showEvent (self, event)
+
+
+    def closeEvent(self,event):
+        QObject.disconnect(self.parent(), SIGNAL("pressed()"), self.close)
+        self.emit(SIGNAL("selected(QString)"),"")
+        self.parent().scene().removeItem(self.fond)
+        QWidget.closeEvent (self, event)
 
 
 class diagLigne(QWidget):   
     def __init__(self, already, portrait, parent=None):
         super(diagLigne, self).__init__(parent)
+        self.fond = QGraphicsRectItem (parent.scene().sceneRect())
+        self.fond.setBrush(QBrush(QColor(0,0,0,153)))
 
         self.hide()
         QObject.connect(self.parent(), SIGNAL("pressed()"), self.close)
@@ -389,26 +469,28 @@ class diagLigne(QWidget):
         self.Metro.setSizePolicy(QSizePolicy(QSizePolicy.Maximum, QSizePolicy.Maximum))
         self.Metro.setMaximumSize(72,72)
         self.Metro.setCheckable(True)
-        self.Metro.setStyleSheet("QPushButton {font: bold 32px;border:8px solid white;color:white;border-radius: 35px;} QPushButton:checked {background-color: white;color:black;}")
+
+
+        self.Metro.setStyleSheet("QPushButton {font: bold 32px;border:8px solid palette(highlighted-text);color:palette(highlighted-text);border-radius: 35px;} QPushButton:checked {background-color: palette(highlight);}")
         self.LayoutBouton.addWidget(self.Metro)
         
         self.Rer = QPushButton("R",self)
         self.Rer.setSizePolicy(QSizePolicy(QSizePolicy.Maximum, QSizePolicy.Maximum))
         self.Rer.setMaximumSize(72,72)
         self.Rer.setCheckable(True)
-        self.Rer.setStyleSheet("QPushButton {font: bold 32px;border:8px solid white;color:white;border-radius: 35px;} QPushButton:checked {background-color: white;color:black;}")
+        self.Rer.setStyleSheet("QPushButton {font: bold 32px;border:8px solid palette(highlighted-text);color:palette(highlighted-text);border-radius: 35px;} QPushButton:checked {background-color: palette(highlight);}")
         self.LayoutBouton.addWidget(self.Rer)
         
         self.Tout = QPushButton("Tout",self)
         self.Tout.setSizePolicy(QSizePolicy(QSizePolicy.Maximum, QSizePolicy.Maximum))
         self.Tout.setMaximumSize(96,72)
-        self.Tout.setStyleSheet("QPushButton {font: bold 32px;border:8px solid white;color:black;border-radius: 35px;background-color: white;} QPushButton:pressed {background-color: blue;border-color:blue;}")
+        self.Tout.setStyleSheet("QPushButton {font: bold 32px;border:8px solid palette(highlight);color:palette(highlight);border-radius: 35px;} QPushButton:pressed {border-color:palette(link-visited);color:palette(link-visited)}")
         self.LayoutBouton.addWidget(self.Tout)
         
         self.Aucun = QPushButton("Rien",self)
         self.Aucun.setSizePolicy(QSizePolicy(QSizePolicy.Maximum, QSizePolicy.Maximum))
         self.Aucun.setMaximumSize(96,72)
-        self.Aucun.setStyleSheet("QPushButton {font: bold 32px;border:8px solid white;color:white;border-radius: 35px;} QPushButton:pressed {color:red;border-color:red;}")
+        self.Aucun.setStyleSheet("QPushButton {font: bold 32px;border:8px solid palette(link-visited);color:palette(link-visited);border-radius: 35px;} QPushButton:pressed {color:palette(highlight);border-color:palette(highlight);}")
         self.LayoutBouton.addWidget(self.Aucun)
         
         self.Tout.clicked.connect(self.selectAll)
@@ -515,7 +597,7 @@ class diagLigne(QWidget):
             else:
                 self.LayoutTram.itemAt(idx-21).widget().setChecked(False)
    
-    def orientation(self):
+    def rotate(self):
         if self.LayoutMetro.columnCount() == 8:
             for idx in range(16):
                 self.LayoutMetro.itemAt(idx).widget().deleteLater()
@@ -527,6 +609,10 @@ class diagLigne(QWidget):
             self.buildMetro(8)
             self.setGeometry(100,00,600,440)
 
+    def showEvent(self,event):
+        self.parent().scene().addItem(self.fond)
+        QWidget.showEvent (self, event)
+
     def closeEvent(self,event):
         selec = []
         for idx in range(25):
@@ -541,6 +627,7 @@ class diagLigne(QWidget):
                     selec.append(idx)
         self.emit(SIGNAL("selection(PyQt_PyObject)"),selec)
         QObject.disconnect(self.parent(), SIGNAL("pressed()"), self.close)
+        self.parent().scene().removeItem(self.fond)
         QWidget.closeEvent (self, event)
 
         
@@ -548,6 +635,8 @@ class diagLigne(QWidget):
 class diagAbout(QWidget):   
     def __init__(self, parent=None):
         super(diagAbout, self).__init__(parent)
+        self.fond = QGraphicsRectItem (parent.scene().sceneRect())
+        self.fond.setBrush(QBrush(QColor(0,0,0,153)))
 #        self.setWindowTitle("Rtap : \xc0 Propos")
         self.setGeometry(100,60,600,300)
 
@@ -556,7 +645,7 @@ class diagAbout(QWidget):
         self.Titre.setFont(QFont('Nokia Sans',48))
         self.Titre.setSizePolicy(QSizePolicy(QSizePolicy.Maximum, QSizePolicy.Fixed))
         self.Logo = QLabel(self)
-        self.Logo.setPixmap(QPixmap("/usr/share/pixmaps/Rtap_About.png"))
+        self.Logo.setPixmap(QPixmap("/home/user/Metro/Rtap_About.png"))
         self.Logo.setAlignment(Qt.AlignCenter)
         self.Text = QLabel(''', les transports \xe0 Paris sur le N900 avec les doigts!
 
@@ -573,13 +662,108 @@ Veuillez reporter les bugs \xe0 la m\xeame adresse, merci!''',self)
 
         self.Fond = QGraphicsRectItem (parent.sceneRect())
         self.Fond.setBrush(QBrush(QColor(0,0,0,153)))
-        
-    def draw(self):
         QObject.connect(self.parent(), SIGNAL("pressed()"), self.close)
-        self.parent().scene().blur()
-        self.show()
+        self.rotate()
+
+    def rotate(self):
+        if self.parent().width() < self.parent().height():
+            self.setGeometry(10,144,460,400)       
+        else:
+            self.setGeometry(100,60,600,340)
+
+    def mousePressEvent(self,event):
+        self.close()
+        QWidget.mousePressEvent (self, event)
+            
+    def showEvent(self,event):
+        self.parent().scene().addItem(self.fond)
+        QWidget.showEvent (self, event)
         
-    def close ( self ):
+    def closeEvent(self,event):
         QObject.disconnect(self.parent(), SIGNAL("pressed()"), self.close)
-        self.parent().scene().unblur()
-        self.hide()
+        self.emit(SIGNAL("closing()"))
+        self.parent().scene().removeItem(self.fond)
+        QWidget.closeEvent (self, event)
+
+class diagAide(QWidget):   
+    def __init__(self, parent=None):
+        super(diagAide, self).__init__(parent)
+        self.fond = QGraphicsRectItem (parent.scene().sceneRect())
+        self.fond.setBrush(QBrush(QColor(0,0,0,153)))
+#        self.setWindowTitle("Rtap : \xc0 Propos")
+        self.setGeometry(100,60,600,300)
+
+
+
+        self.Layout = QVBoxLayout(self)
+        self.scroll = QScrollArea(self)
+        self.Titre = QLabel(' Aide ',self)
+        self.Titre.setFont(QFont('Nokia Sans',48))
+        self.Titre.setSizePolicy(QSizePolicy(QSizePolicy.Maximum, QSizePolicy.Fixed))
+        self.Text = QTextEdit('''<p align="center"><span style=" font-size:32pt; font-weight:600;">Carte</span></p>
+<p><b>Selection d'une station:</b></p>
+<p>Double-clique sur la station.</p>
+<p><br /><b>D\xe9placement:</b></p>
+<p>Clique et gliss\xe9.<br /></p>
+<p><b>Zoom: </b></p>
+<p>Double-clique et gliss\xe9 vers le bas/droite.
+<br /><br /><b>d\xe9Zoom: </b></p>
+<p>Double-clique et gliss\xe9 vers le haut/gauche.</p>
+<p></p>
+<p><br /><b>GPS:</b></p>
+<p><img src="/usr/share/icons/hicolor/32x32/hildon/camera_gps_location.png" width="32" height="32"/> : Double-clique pour activer la localisation.</p>
+<p><img src="/usr/share/icons/hicolor/48x48/hildon/location_applet_track_start.png" width="32" height="32"/> : GPS activ\xe9.</p>
+<p><img src="/usr/share/icons/hicolor/48x48/hildon/location_applet_track_stop_ani.png" width="32" height="32"/> : Localisation pr\xe9cise.</p>
+<p><img src="/usr/share/icons/hicolor/48x48/hildon/sketch_circle.png" width="32" height="32"/> : GPS d\xe9sactiv\xe9 mais position enregistr\xe9e.</p>
+<p>Clique long (1s) pour centrer la carte la position GPS.</p>
+<p></p>
+<p><br /><b>Panneaux:</b></p>
+<p>Clique pour cacher et d\xe9selectionner la station.</p>
+<p></p>
+<p><img src="/usr/share/icons/hicolor/48x48/hildon/statusarea_sharing_pending.png" width="32" height="32"/> : Calculer l'itin\xe9raire.</p>
+<p><img src="/usr/share/icons/hicolor/48x48/hildon/statusarea_sharing.png" width="32" height="32"/> : Calcul en cours.</p>
+<p><img src="/usr/share/icons/hicolor/48x48/hildon/camera_playback.png" width="32" height="32"/> : Parcours de l'itin\xe9raire sur la carte</p>
+<p><br /></p>
+<p align="center"><span style=" font-size:32pt; font-weight:600;">Menu:</span></p>
+<p><br /><b>Recherche:</b></p>
+<p>Selection: Double clique.</p>
+<p>Sortir: Clique ailleurs.</p>
+<p></p>
+<p><br /><b>Selection des lignes:</b></p>
+<p>Selection/D\xe9selection : Clique</p>
+<p>Sortir/Valider: Clique ailleurs.</p>
+<p></p>
+<p><br /><b>Aide:</b></p>
+<p>Sortir: Clique ailleurs.</p>
+<p></p>
+<p><br /><b>\xc0 Propos:</b></p>
+<p>Sortir: Clique ailleurs.</p>
+<p><br /></p>''',self.scroll)
+        self.Text.setFont(QFont('Nokia Sans',18))
+        self.Text.setSizePolicy(QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed))
+#        self.Text.setWordWrap(True)
+        
+        self.Layout.addWidget(self.Titre)
+        self.Layout.addWidget(self.scroll)
+        self.scroll.setWidget(self.Text)
+        QObject.connect(self.parent(), SIGNAL("pressed()"), self.close)
+        self.rotate()
+
+    def rotate(self):
+        if self.parent().width() < self.parent().height():
+            self.setGeometry(10,50,460,600)
+            self.Text.resize(self.width()-40,2100)        
+        else:
+            self.setGeometry(100,60,600,340)
+            self.Text.resize(self.width()-40,2000)
+
+            
+    def showEvent(self,event):
+        self.parent().scene().addItem(self.fond)
+        QWidget.showEvent (self, event)
+        
+    def closeEvent(self,event):
+        QObject.disconnect(self.parent(), SIGNAL("pressed()"), self.close)
+        self.emit(SIGNAL("closing()"))
+        self.parent().scene().removeItem(self.fond)
+        QWidget.closeEvent (self, event)
