@@ -16,9 +16,9 @@ def gps(S):
     return graph[S]['coord']
     
 def X(S):
-    return graph[S].posX
+    return graph[S].x()
 def Y(S):
-    return graph[S].posY
+    return graph[S].y()
 def color(S):
     return graph[S].colorIni.color()
 
@@ -89,7 +89,7 @@ def calc(Deb, Fin,G):
                                                 
 
                                                 #if l__successorsColor[l__current_edge] != QtGui.QColor(103,47,143):
-                                                l__newTentativeDistance = int(noeuds[l__current_vertex][0] + math.sqrt( (graph[l__current_vertex].posX - graph[l__successor].posX)**2 + (graph[l__current_vertex].posY - graph[l__successor].posY)**2)) + 60.
+                                                l__newTentativeDistance = int(noeuds[l__current_vertex][0] + math.sqrt( (graph[l__current_vertex].x() - graph[l__successor].x())**2 + (graph[l__current_vertex].y() - graph[l__successor].y())**2)) + 60.
                                                 #else:
                                                 #   l__newTentativeDistance = noeuds[l__current_vertex][0] + math.sqrt( (X(l__current_vertex) - X(l__successor))**2 + (Y(l__current_vertex) - Y(l__successor))**2)*.75
                                                 
