@@ -203,44 +203,45 @@ class Ui_MainWindow(QMainWindow):
 
         
     def search(self):
-        value , ok = QInputDialog.getText( self.view, "Rtap : Recherche", "Saisissez les termes de votre recherche.", )
-        result = []
-        if ok:
-            self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, True)
-            for element in graph:
-                if str(value) in element:
-                    result += [element]
-            self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, False)
-            if len(result) == 0:
-                QMaemo5InformationBox.information( self, 'La recherche n\'a donn\xe9 aucun r\xe9sultat.' )
-            elif len(result) == 1:
-                self.setSelec(result[0])
-                
-                self.view.goTo(graph[result[0]].Pos(),self.view.getScale())
-                self.view.animPar.start()
-            elif len(result) > 1:
-                Selec , ok = QInputDialog.getItem ( self.view, "Rtap : Recherche", "Liste des r\xe9sultats. Choisissez une station :", result, 0, False)
-                if ok:
-                    self.setSelec(Selec)
-                    self.view.goTo(graph[str(Selec)].Pos(),self.view.getScale())
-                    self.view.animPar.start()
-    
-                    if Selec == 'GPS':
-                        self.gps.selec()
-                        self.gpsCenter()
+        self.stop()
+        self.panDepart.hide()
+        self.panArrivee.hide()
+        self.panAction.hide()
+        self.gpsButton.hide()
+        self.Temps.hide()
+
+        cherche = classes.diagSearch(graph ,self.view)
+        QObject.connect(app.desktop(), SIGNAL("resized(int)"), cherche.rotate)
+        QObject.connect(cherche, SIGNAL("selected(QString)"), self.searchProcess)
+        cherche.show()
+
+    def searchProcess(self,text):
+        self.panDepart.show()
+        self.panArrivee.show()
+        self.panAction.show()
+        self.gpsButton.show()
+
+        if text != "":
+            self.setSelec(text)
+            self.view.goTo(graph[str(text)].pos(),self.view.getScale())
+            self.view.animPar.start()
+
+        
                     
     def selecLignes(self):
         self.stop()
-        self.deselec(self.Selec[1])
-        self.deselec(self.Selec[0])
+        self.panDepart.hide()
+        self.panArrivee.hide()
+        self.panAction.hide()
+        self.gpsButton.hide()
+        self.Temps.hide()
 
         graph.clear()
         boole = (app.desktop().screenGeometry().width() < app.desktop().screenGeometry().height())
-        diag = classes.diagLigne(self.Lignes,boole,self.view)
-        QObject.connect(diag,SIGNAL("selection(PyQt_PyObject)"),self.selecLignesProcess)
-        QObject.connect(app.desktop(), SIGNAL("resized(int)"), diag.orientation)
-        self.scene.blur()
-        diag.show()
+        ligne = classes.diagLigne(self.Lignes,boole,self.view)
+        QObject.connect(ligne,SIGNAL("selection(PyQt_PyObject)"),self.selecLignesProcess)
+        QObject.connect(app.desktop(), SIGNAL("resized(int)"), ligne.rotate)
+        ligne.show()
         
     def selecLignesProcess(self,liste):
         reload(station)
@@ -253,7 +254,54 @@ class Ui_MainWindow(QMainWindow):
                     nom = QGraphicsTextItem (stop,graph[stop])
                     nom.setFont(QFont ( "Nokia Sans",_RAYON/2  ,63 ))
                     nom.setDefaultTextColor(graph[stop].color.color().lighter())
-        self.scene.unblur()
+
+        self.panDepart.show()
+        self.panArrivee.show()
+        self.panAction.show()
+        self.gpsButton.show()
+        
+        dep,arr = self.Selec
+        self.deselec(self.Selec[0])
+        self.deselec(self.Selec[1])
+        if dep in graph:
+            self.setSelec(dep)
+        if arr in graph:
+             self.setSelec(arr)
+
+    def about(self):
+        self.stop()
+        self.panDepart.hide()
+        self.panArrivee.hide()
+        self.panAction.hide()
+        self.gpsButton.hide()
+        self.Temps.hide()
+
+        about = classes.diagAbout(self.view)
+        QObject.connect(app.desktop(), SIGNAL("resized(int)"), about.rotate)
+        QObject.connect(about,SIGNAL("closing()"),self.endMenu)
+        about.show()
+
+
+
+    def aide(self):
+        self.stop()
+        self.panDepart.hide()
+        self.panArrivee.hide()
+        self.panAction.hide()
+        self.gpsButton.hide()
+        self.Temps.hide()
+
+        aide = classes.diagAide(self.view)
+        QObject.connect(app.desktop(), SIGNAL("resized(int)"), aide.rotate)
+        QObject.connect(aide,SIGNAL("closing()"),self.endMenu)
+        aide.show()
+
+    def endMenu(self):
+        self.panDepart.show()
+        self.panArrivee.show()
+        self.panAction.show()
+        self.gpsButton.show()
+
 
     def setSelec(self,Name):
         
@@ -268,7 +316,8 @@ class Ui_MainWindow(QMainWindow):
                 self.gps.deselec()
                 for item in self.CheminItem:
                     self.scene.removeItem(item)
-                self.scene.unblur()
+                if self.scene.blurred:
+                    self.scene.unblur()
                 self.panDepart.playX(w)
                 self.panArrivee.playX(w)
                 self.panAction.playX(w)
@@ -354,7 +403,8 @@ class Ui_MainWindow(QMainWindow):
     def deselec(self,Nom):
         w = self.width()
         h = self.height()
-        self.scene.unblur()
+        if self.scene.blurred:
+            self.scene.unblur()
         for item in self.CheminItem:
             self.scene.removeItem(item)
         self.Temps.hide()
@@ -484,7 +534,7 @@ class Ui_MainWindow(QMainWindow):
         self.panAction.move(self.panAction.x(),app.desktop().screenGeometry().height()/2-76)
         self.view.translate(-150,200)
         
-        self.gpsButton.move(16,app.desktop().screenGeometry().height()-80-56)
+        self.gpsButton.move(0,app.desktop().screenGeometry().height()-80-56)
 
         if self.panDepart.state :
             self.panDepart.move(app.desktop().screenGeometry().width()-min(290,self.panDepart.width()),self.panDepart.y())
@@ -493,10 +543,6 @@ class Ui_MainWindow(QMainWindow):
         if self.panAction.state :
             self.panAction.move(app.desktop().screenGeometry().width()-100,self.panAction.y())
             self.panAction.animMargin.start()
-        if app.desktop().screenGeometry().width() < app.desktop().screenGeometry().height():
-            self.about.setGeometry(10,144,460,400)       
-        else:
-            self.about.setGeometry(100,60,600,340)
 #        if self.panAction.toggle :  
 #            x = (app.desktop().screenGeometry().width() - self.Temps.width())/2
 #            self.Temps.move(x,app.desktop().screenGeometry().height() - 80 - 56)
@@ -659,7 +705,7 @@ class Ui_MainWindow(QMainWindow):
         QObject.connect(self.gpsButton, SIGNAL("gpsOn"), self.addGPS)
         QObject.connect(self.gpsButton, SIGNAL("gpsOff"), self.closeSession)
         QObject.connect(self.gpsButton, SIGNAL("gpsCenter"), self.gpsCenter)
-        self.gpsButton.setGeometry(16,app.desktop().screenGeometry().height()-80-56,80,80)
+        self.gpsButton.setGeometry(0,app.desktop().screenGeometry().height()-80-56,80,80)
         self.gpsButton.show()
 
 ######### Menu
@@ -675,20 +721,20 @@ class Ui_MainWindow(QMainWindow):
         menubar.addAction(menuLignes)
         QObject.connect(menuLignes, SIGNAL("triggered()"), self.selecLignes)
 
+        menuAide = QAction("Aide",self)
+        menubar.addAction(menuAide)
+        QObject.connect(menuAide, SIGNAL("triggered()"), self.aide)
+
         menuAbout = QAction("\xc0 Propos",self)
         menubar.addAction(menuAbout)
-        self.about = classes.diagAbout(self.view)
-        self.about.hide()
-        QObject.connect(menuAbout, SIGNAL("triggered()"), self.about.draw)
+        QObject.connect(menuAbout, SIGNAL("triggered()"), self.about)
 
 #########
 
         if app.desktop().screenGeometry().width() < app.desktop().screenGeometry().height():
             self.view.centerOn(1900.,-500) 
-            self.about.setGeometry(10,144,460,400)       
         else:
             self.view.centerOn(1750.,-400)
-            self.about.setGeometry(100,60,600,340)
         self.view.show()
         self.view.update()
 
